@@ -1,5 +1,5 @@
 mod dir;
 mod fs;
 
-pub use dir::StaticDir;
+pub use dir::{Options, StaticDir};
 pub use fs::StaticFile;
